% GenerateSurferTXT.m Generation of TXT format for Surfer acoustic mapping.
% This script generates a TXT needed by Surfer to create acoustic maps 
% from the SPS Irs 
%
% INPUT
% SpsIrs
%
% OUTPUT
% TXT for Surfer
%
% Authors: Daniel Pinardi, Marco Binelli.
% University of Parma.
% 2017

clear all
close all
clc

%% OUTPUT FILENAME
filename1 = '../AnalisysResults/surferTxt/Eigenmike_lowpassFilt';
filename2 = '../AnalisysResults/surferTxt/Eigenmike_unfiltered';

%% LOW PASS FILTERING PARAMETERS
fc                      = 500;          % Cutoff Frequency [Hz]
order                   = 8;            % filter order

%% LOAD DATA FROM FILES
% 32ch SPS IRs
load('../AnalisysResults/spsIrs/spsIrs');

%% IR filtering - Butterworth low pass
[b,a]                   = butter( order, fc/( fs/2 ) );                     % Generate lowpass filter coefficient
irLength                = length( spsIrs );                                 % number of samples for each IR
virtualMicNumber        = size( spsIrs, 2 );                                % number of virtual microphones
spsIrsLowPassFilt       = zeros( irLength, virtualMicNumber );              % per allocate

for j = 1:32
    spsIrsLowPassFilt( :, j ) = filter( b, a, spsIrs( :, j ) );
end

%% COMPUTE FILTERED SPL
rmsLowPassFilt          = rms( spsIrsLowPassFilt )';
p0                      = 0.00002;                                          % Reference value for pressure dB conversion [Pa] 
spsLowPassFilt          = 20 * log10( rmsLowPassFilt / p0 );

%% COMPUTE TOTAL SPL WITHOUT FILTERING
totalRms                = rms( spsIrs )';                                   % compute total rms value
p0                      = 0.00002;                                          % Reference value for pressure dB conversion [Pa] 
totalSpl                = 20 * log10( totalRms / p0 );                      % convert rms to SPL

%% Import the 32 coordinate (azimuth and elevation) for EigenMike SPS
GenerateEM32Dir
azimuth                 = EM32Dir(:,4);
elevation               = EM32Dir(:,5);

%% Exporting data for Surfer visualization
% correcting azimuth for Surfer unwrapping format
for w = 1:32
    if azimuth(w) > 180
       azimuth(w) = azimuth(w) - 360;
    end
end
azimuth = -azimuth;

% % correcting elevation to match panoramic background photo
% for w = 1:32
%     elevation(w) = elevation(w) - 45;
% end

% Create export matrix
surferExportMatrix1       = [ azimuth, elevation, spsLowPassFilt ];
surferExportMatrix2       = [ azimuth, elevation, totalSpl ];

% Write matrix to file
dlmwrite( [filename1 '_SurferMap.txt'], surferExportMatrix1, 'delimiter', '\t', 'newline', 'pc' );
dlmwrite( [filename2 '_SurferMap.txt'], surferExportMatrix2, 'delimiter', '\t', 'newline', 'pc' );
