% checkTFnfft2.m This function compute four different tranfer function and plot
% result

function [ nfft ] = checkTFnfft2( referenceMic, audioSignal )
     
fprintf( 'Evaluating nfft value for transfer function\n' );

audioSignal     = mean( audioSignal, 2 );
referenceMic    = referenceMic( :, 1 );
stepSize        = 1600;

numbersFrame = floor( length( audioSignal ) / 65536 );
if numbersFrame > 10
    numbersFrame = 10;
end

limit = numbersFrame * 65536 + stepSize;

bufferSizeVec = [ 8192, 16384, 32768, 65536 ];

for j = 1 : size( bufferSizeVec, 2 )
    
    bufferSizeTry = bufferSizeVec( j );
    figure( 'NumberTitle', 'off', 'Name', [ 'BufferSize: ' num2str( bufferSizeTry ) ] );
     
    if j == 1
        nfftVec = [ 512, 1024, 2048, 4096 ];
    elseif j == 2
        nfftVec = [ 1024, 2048, 4096, 8192 ];
    elseif j == 3
        nfftVec = [ 2048, 4096, 8192, 16384 ];
    else
        nfftVec = [ 4096, 8192, 16384, 32768 ];
    end   
           
    for i = 1 : length( nfftVec )

        nfft                    = nfftVec( i );
        
        for blockIndex = 1 : floor( limit / bufferSizeTry )
            
            refMicChunk         = referenceMic( (blockIndex-1) * stepSize + 1 : (blockIndex-1) * stepSize + bufferSizeTry, : );
            audioSignalChunk    = audioSignal( (blockIndex-1) * stepSize + 1 : (blockIndex-1) * stepSize + bufferSizeTry, : );
            
            transferFunction    = tfestimate( refMicChunk, audioSignalChunk, hann( nfft ), nfft/4, nfft );
            % transferFunction    = tfestimate( audioSignalChunk, refMicChunk, hann( nfft ), nfft/4, nfft );
            transferFunction    = [ 0; transferFunction( 2 : end - 1,: ); ...
                                    0; flipud( conj( transferFunction( 2 : end - 1, : ) ) ) ];

            tfIR(:,blockIndex)  = fftshift( ifft( transferFunction ) );
        end
        
        tfIR                    = mean( tfIR, 2, 'omitnan' );
        
        subplot( 2, 2, i )
        plot( tfIR )
        title( num2str( nfft ) )
        xlim( [ 0 nfft ] )
        clear tfIR
    end
end
fprintf( 'Type CTRL+C to abort and change bufferSize value or ...\n' )
prompt                      = '...type nfft value: ';
nfft                        = input( prompt );

close all
