% computeComplexSum.m This function compute complex sum for filtering in freq. domain

function [ complexSum, freqTot ] = computeComplexSum( spsFormat, coherenceEnable, ...
                        refMicNumber, referenceMic, virtualMicNumber, nfft, fs, overlap )

freqTot             = linspace( 0, fs/2, nfft/2 + 1 );
fftStep             = round( nfft * ( 1 - overlap ) );
win                 = single( hann( nfft ) );
energyNormFactor    = ( rms( win ) ) ^-1;

if coherenceEnable % coherent noise elaboration
    
    stepNumber              = round( length( referenceMic ) / fftStep );
    complexSum              = single( zeros( virtualMicNumber, nfft/2+1, refMicNumber ) );
    
    for i = 1 : refMicNumber

        transferFunction    = tfestimate( referenceMic( :, i ), spsFormat, hann( nfft ), nfft/2, nfft );
        referenceMicTmp     = [ referenceMic( :, i ) ; zeros( nfft, 1 ) ]; 
        coherentSpsNoise    = single( zeros( nfft/2+1, virtualMicNumber, stepNumber ) );
        
        for j = 1 : stepNumber
            
            chunkFft        = referenceMicTmp( ( j - 1 ) * fftStep + 1 : ( j - 1 ) * fftStep + nfft );
            chunkFftWin     = chunkFft .* win;
            frf             = ( fft( chunkFftWin, nfft ) ) / nfft;
            coherentSpsNoise(:,:,j) = 2 * frf( 1 : nfft/2 + 1, : ) * energyNormFactor .* transferFunction;
        end
        
        clear frf chunkFft chunkFftWin

        complexSumI         = real( coherentSpsNoise ).^2 + imag( coherentSpsNoise ).^2;
        clear coherentSpsNoise
        complexSum(:,:,i)   = mean( complexSumI, 3 )';
        clear complexSumI
    end
    
else
    
    stepNumber          = round( length( spsFormat ) / fftStep );
    spsFormat           = [ spsFormat ; zeros( nfft, virtualMicNumber ) ]; 
    halfFrf             = single( zeros( nfft/2+1, virtualMicNumber, stepNumber ) );
    
    for i = 1 : stepNumber
        chunkFft        = spsFormat( ( i - 1 ) * fftStep + 1 : ( i - 1 ) * fftStep + nfft, : );
        chunkFftWin     = chunkFft .* win;
        frf             = ( fft( chunkFftWin, nfft, 1 ) ) / nfft;
        halfFrf(:,:,i)  = 2 * frf( 1 : nfft/2 + 1, : ) * energyNormFactor;
    end
    
    clear frf spsFormat win chunkFft chunkFftWin
    complexSum          = real( halfFrf ).^2 + imag( halfFrf ).^2;
    complexSum          = mean( complexSum, 3 )';
    
end
