% computeSPLbandpassfilt.m This function compute bandpass filtered spl from complex sum

function [ splBandPassFilt ] = computeSPLbandpassfilt( complexSum, fullScaleLevel, freqTot, bandpassLowCutFreq, bandpassHighCutFreq, ...
                               spsMean, fs, nfft, overlap, plotSignalEnable, limitFreq, coherenceEnable, refMicNumber )
                                
tmp                         = abs( freqTot - bandpassLowCutFreq );
[~, idxLowBP]               = min( tmp );                                   % index of closest value
tmp                         = abs( freqTot - bandpassHighCutFreq );
[~, idxHighBP]              = min( tmp );                                   % index of closest value

if coherenceEnable
    
    for i = 1 : refMicNumber
        complexSumTmp       = complexSum( : ,:, i );
        rmsBandPassFilt( i, : ) = ( sqrt( sum( complexSumTmp( :, idxLowBP:idxHighBP ), 2 ) ) / sqrt( 2 ) )';
    end
    
else
    
    rmsBandPassFilt         = ( sqrt( sum( complexSum(:, idxLowBP:idxHighBP ), 2 ) ) / sqrt( 2 ) )';
    
end

splBandPassFilt             = fullScaleLevel + 20 * log10( rmsBandPassFilt ); % convert rms to SPL

if plotSignalEnable
        
    figure    
    [ amplitudeFrfdB, freq ] = fftPinardi( spsMean, fs, nfft, overlap );
    semilogx( freq, amplitudeFrfdB )
    hold on
    line( [ bandpassLowCutFreq bandpassLowCutFreq ], limitFreq, 'Color', 'red' );
    line( [ bandpassHighCutFreq bandpassHighCutFreq ], limitFreq, 'Color', 'red' );
    title( 'Band pass ')
    xlim( [ 20 20000 ] )
    ylim( limitFreq )
    hold off
    
end
