% computeSPLoctavefilt.m This function compute octave band filtered spl from complex sum

function [ splOctaveFilt, centerFreq ] = computeSPLoctavefilt( fs, firstOctaveBand, lastOctaveBand, plotSignalEnable, scrsz, ...
                             freqTot, complexSum, spsMean, nfft, overlap, limitFreq, fullScaleLevel, coherenceEnable, refMicNumber )
                                
% Octave band filters generation
bandsPerOctave          = 1;
octaveBandFilterOrder   = 10;                                               % Filter Order
centerFreq              = 1000;                                             % Center Frequency (Hz)
f                       = fdesign.octave( bandsPerOctave, 'Class 1', 'N,F0', octaveBandFilterOrder, centerFreq, fs );
centerFreq              = validfrequencies( f );                            % calc. approx center frequencies
centerFreq              = centerFreq( firstOctaveBand : lastOctaveBand );   % selected freq range
octaveBandsNumber       = length( centerFreq );                             % number of bands selected

% Octave band filters computation
if plotSignalEnable
    m                   = ceil( octaveBandsNumber / 2 );
    figure( 'Position', [ 1 1 scrsz(3) scrsz(4) ] );
    [ amplitudeFrfdB, freq ] = fftPinardi( spsMean, fs, nfft, overlap );
end

for i = 1 : octaveBandsNumber
    lowCutFreq          = centerFreq( i ) / sqrt( 2 );
    highCutFreq         = lowCutFreq * 2;
    
    tmp                 = abs( freqTot - lowCutFreq );
    [~, idxLowOctave]   = min( tmp );                                       % index of closest value
    tmp                 = abs( freqTot - highCutFreq );
    [~, idxHighOctave]  = min( tmp );                                       % index of closest value
    
    if coherenceEnable
        
        for j = 1 : refMicNumber
            complexSumTmp            = complexSum( : ,:, j );
            rmsOctaveFilt( i, :, j ) = ( sqrt( sum( complexSumTmp( :, idxLowOctave:idxHighOctave ), 2 ) ) / sqrt( 2 ) )';
        end
        
    else
        
        rmsOctaveFilt( i, : ) = ( sqrt( sum( complexSum( :, idxLowOctave:idxHighOctave), 2 ) ) / sqrt( 2 ) )';
    
    end
    
    if plotSignalEnable

        % plot FFT
        subplot( m, 2, i);
        tmp                 = abs( freq - lowCutFreq );
        [ ~, idxLowOctave ] = min( tmp );                                   % index of closest value
        tmp                 = abs( freq - highCutFreq );
        [ ~, idxHighOctave ] = min( tmp );                                  % index of closest value

        semilogx( freq( idxLowOctave : idxHighOctave ), amplitudeFrfdB( idxLowOctave : idxHighOctave ) );	 	 
        hold on
        line( [ centerFreq(i) centerFreq(i) ], limitFreq, 'Color', 'red' );
        title( [ 'Filtering octave band: ' num2str( centerFreq(i) ) ] );
        xlim( [ 20 20000 ] )
        ylim( limitFreq )
        hold off
    end     
end

splOctaveFilt           = fullScaleLevel + 20 * log10( rmsOctaveFilt );     % convert rms to SPL
