% frameProcessing.m This function adjust length of signal for video analysis

function [ ZI ] = frameProcessing( blockIndex, coherenceEnable, referenceMic, stepSize, bufferSize, ...
           totalTFenable, mimoEnable, spsFormat, nfft, filteringEnable, freqWindowing, refMicNumber, ...
           fftStepNumber, fftStep, win, energyFactorWin, virtualMicNumber, fullScaleLevel, extX, extY, ...
           extXI, extYI, surfpoint, transferFunction, fftNormFactor )
                
    if coherenceEnable
        
        refMicChunk         = referenceMic( (blockIndex-1) * stepSize + 1 : (blockIndex-1) * stepSize + bufferSize, : );
        
        if totalTFenable == 0 % update transfer function for each frame

            spsFormatChunk      = spsFormat( (blockIndex-1) * stepSize + 1 : (blockIndex-1) * stepSize + bufferSize, : );
       
            if mimoEnable
                transferFunction = tfestimate( refMicChunk, spsFormatChunk, hann( nfft ), nfft/2, nfft, 'mimo' );
            else
                transferFunction = tfestimate( refMicChunk, spsFormatChunk, hann( nfft ), nfft/2, nfft );
            end
            
            if filteringEnable
                transferFunction = transferFunction .* freqWindowing;
            end
        end            
               
        % calculating partitioned FFT on referenceMic
        if nfft > bufferSize
            refMicChunk      = [ refMicChunk ; zeros( nfft, refMicNumber ) ]; % zero padding
        end
        
        for i = 1 : fftStepNumber
            chunkFft        = refMicChunk( ( i - 1 ) * fftStep + 1 : ( i - 1 ) * fftStep + nfft, : );
            chunkFft        = chunkFft .* win;
            frfChunk        = fft( chunkFft, nfft, 1 ) / ( fftNormFactor / ( 2*energyFactorWin) ) ;
            frfChunk        = frfChunk( 1 : nfft/2 + 1, : );
            
            if mimoEnable
                % adapting of fft matrix to be compatible with the Transfer Function Matrix
                frfChunk    = repelem( frfChunk, 1, 1, virtualMicNumber );       
                frfChunk    = permute( frfChunk, [ 1 3 2 ] );
                frf(:,:,i)  = max( ( frfChunk .* transferFunction ) , [], 3 ); % coherent noise                         
            else
                frf(:,:,i)  = frfChunk .* transferFunction;                 % coherent noise
            end
        end
                   
    else
        
        % calculating total FFT on spsFormat
        frfChunk            = spsFormat( (blockIndex-1) * stepSize + 1 : (blockIndex-1) * stepSize + bufferSize, : );
        
        if blockIndex == 1
            fftw('dwisdom',[]);
            fftw('planner','measure');
            fft( frfChunk, nfft, 1 ) / (nfft/2);
            fftinfo         = fftw('dwisdom');
            fftw('dwisdom',fftinfo);
        end
        
        frfhalf             = fft( frfChunk, nfft, 1 ) / (nfft/2);

        if filteringEnable                   
            frf             = frfhalf( 1 : nfft/2 + 1, : ) .* freqWindowing;
        else
            frf             = frfhalf( 1 : nfft/2 + 1, : );
        end
              
    end
    
    complexSum              = mean( (real( frf ).^2 + imag( frf ).^2), 3 );
    rmsChunk                = ( sum( complexSum, 1, 'omitnan' ) )' ./ 2;
    splChunk                = ( 10 * log10( rmsChunk ) + fullScaleLevel )';
        
    if virtualMicNumber == 122                                              % replicate SPL value on poles
        [ splChunk ]        = extendSPL122dir( splChunk );
    end
      
    [ ZI ] = splInterpolation( double( splChunk ), virtualMicNumber, extX, extY, extXI, extYI, surfpoint );
    