% panAmbix.m This function resolve Ambisonics equation (depending on
% azimuth and elevation) and collocate virtual sources in space.

function [ ambixAudio ] = panAmbix( azimuth, elevation, spsFormatAudio )

A                   = zeros( 1, 16 );       % preallocate coefficient matrix for Ambisonics
virtualMicSources   = size( spsFormatAudio, 2 );   % number of sources to pan
ambixAudio          = zeros( length( spsFormatAudio ), 16, virtualMicSources ); % preallocate

for j = 1 : virtualMicSources

    % first order
    A(1,1)  = 1;                                                            % W
    A(1,2)  = sin(azimuth(j))*cos(elevation(j));                            % Y
    A(1,3)  = sin(elevation(j));                                            % Z
    A(1,4)  = cos(azimuth(j))*cos(elevation(j));                            % X
    % second order         
    A(1,5)  = sqrt(3/4)*sin(2*azimuth(j))*(cos(elevation(j)))^2;            % R
    A(1,6)  = sqrt(3/4)*sin(azimuth(j))*sin(2*elevation(j));                % S
    A(1,7)  = (1/2)*(3*(sin(elevation(j)))^2 -1);                           % T
    A(1,8)  = sqrt(3/4)*cos(azimuth(j))*sin(2*elevation(j));                % U
    A(1,9)  = sqrt(3/4)*cos(2*azimuth(j))*(cos(elevation(j)))^2;            % V
    % third order       
    A(1,10) = sqrt(5/8)*sin(3*azimuth(j))*(cos(elevation(j)))^3;                         % K
    A(1,11) = sqrt(15/4)*sin(2*azimuth(j))*sin(elevation(j))*(cos(elevation(j)))^2;      % L
    A(1,12) = sqrt(3/8)*sin(azimuth(j))*cos(elevation(j))*(5*(sin(elevation(j)))^2 - 1); % M
    A(1,13) = (1/2)*sin(elevation(j))*(5*(sin(elevation(j)))^2-3);                       % N
    A(1,14) = sqrt(3/8)*cos(azimuth(j))*cos(elevation(j))*(5*(sin(elevation(j)))^2 -1);  % O
    A(1,15) = sqrt(15/4)*cos(2*azimuth(j))*cos(elevation(j))*(sin(elevation(j)))^2;      % P
    A(1,16) = sqrt(5/8)*cos(3*azimuth(j))*(cos(elevation(j)))^3;                         % Q

    ambixAudio( :, :, j ) = spsFormatAudio( :, j ) .* A; % generate Ambix format for each virtual source
end

ambixAudio = sum( ambixAudio, 3 ); % sum all sources
    