% saveColorMap.m This function save each colormap to proper folder with
% proper name and title

function [ ] = saveColorMap( recordedFileName, spsFilterMatrixFileName, mapsFolder, lowPassCutFreq, ...
                             bandpassLowCutFreq, bandpassHighCutFreq, centerFreq, imageIndex, refName )

Position                = recordedFileName(1:end-4);
PositionFolder          = [ recordedFileName(1:end-4) '_' spsFilterMatrixFileName(1:end-4) '_' refName ];

if imageIndex == 1

    title( [ 'Unfiltered map - ' spsFilterMatrixFileName(1:end-4) ' - ' recordedFileName(1:end-4) ' - ' refName ] );

    mapsFolderPosition  = [ mapsFolder 'byPosition/' ];
    mkdir( [ mapsFolderPosition PositionFolder ] );
    print( [ mapsFolderPosition PositionFolder filesep 'Unfiltered_' Position '_' spsFilterMatrixFileName(1:end-4) '_' refName '.png' ], '-dpng' );

    mapsFolderPosition  = [ mapsFolder 'byFrequency/' ];
    mkdir( [ mapsFolderPosition 'Unfiltered/' ] );      
    print( [ mapsFolderPosition 'Unfiltered' filesep 'Unfiltered_' Position '_' spsFilterMatrixFileName(1:end-4) '_' refName '.png' ], '-dpng' );  

elseif imageIndex == 2

    title( [ 'Low pass filtered map at ' num2str( lowPassCutFreq ) 'Hz - ' spsFilterMatrixFileName(1:end-4) ' - ' recordedFileName(1:end-4) ' - ' refName ] );

    mapsFolderPosition  = [ mapsFolder 'byPosition/' ];
    mkdir( [ mapsFolderPosition PositionFolder ] );
    print( [ mapsFolderPosition PositionFolder filesep 'LowpassFiltered_' num2str( lowPassCutFreq ) '_' Position '_' spsFilterMatrixFileName(1:end-4) '_' refName '.png' ], '-dpng' ); 

    mapsFolderPosition  = [ mapsFolder 'byFrequency/' ];
    mkdir( [ mapsFolderPosition 'LowPass/' ] );  
    print( [ mapsFolderPosition 'LowPass' filesep 'LowpassFiltered_' num2str( lowPassCutFreq ) '_' Position '_' spsFilterMatrixFileName(1:end-4) '_' refName '.png' ], '-dpng' ); 

elseif imageIndex == 3

    title( [ 'Bandpass filtered map between ' num2str( bandpassLowCutFreq ) 'Hz and ' num2str( bandpassHighCutFreq ) 'Hz - ' spsFilterMatrixFileName(1:end-4) ' - ' recordedFileName(1:end-4) ' - ' refName ] );

    mapsFolderPosition  = [ mapsFolder 'byPosition/' ];
    mkdir( [ mapsFolderPosition PositionFolder ] );
    print( [ mapsFolderPosition PositionFolder filesep 'BandpassFiltered_' num2str( bandpassLowCutFreq ) '_' num2str( bandpassHighCutFreq ) '_' Position '_' spsFilterMatrixFileName(1:end-4) '_' refName '.png' ], '-dpng' ); 

    mapsFolderPosition  = [ mapsFolder 'byFrequency/' ];
    mkdir( [ mapsFolderPosition 'BandPass/' ] );  
    print( [ mapsFolderPosition 'BandPass' filesep 'BandpassFiltered_' num2str( bandpassLowCutFreq ) '_' num2str( bandpassHighCutFreq ) '_' Position '_' spsFilterMatrixFileName(1:end-4) '_' refName '.png' ], '-dpng' );

else

    title( [ 'Octave band filtered map, center freq. ' num2str( centerFreq( imageIndex - 3 ) ) 'Hz - ' spsFilterMatrixFileName(1:end-4) ' - ' recordedFileName(1:end-4) ' - ' refName ] );

    mapsFolderPosition  = [ mapsFolder 'byPosition/' ];
    mkdir( [ mapsFolderPosition PositionFolder ] );
    print( [ mapsFolderPosition PositionFolder filesep 'OctaveFiltered_' num2str( centerFreq( imageIndex - 3 ) ) '_' Position '_' spsFilterMatrixFileName(1:end-4) '_' refName '.png' ], '-dpng' ); 

    mapsFolderPosition  = [ mapsFolder 'byFrequency/' ];
    octave              = [ 'Octave_' num2str( centerFreq( imageIndex - 3 ) ) ];
    mkdir( [ mapsFolderPosition octave ] ); 
    print( [ mapsFolderPosition octave filesep 'OctaveFiltered_' num2str( centerFreq( imageIndex - 3 ) ) '_' Position '_' spsFilterMatrixFileName(1:end-4) '_' refName '.png' ], '-dpng' ); 

end