% selectSPSsource.m This function permit to choose a certain number of sources from
% SPS format, and define their position with azimuth and elevation,
% clicking on a background image

function [ spsFormatAudio, azimuth, elevation ] = selectSPSsource( backgroundFrame, X, Y, spsFormat )

virtualMicNumber    = size( spsFormat, 2 );
imageWidth          = size( backgroundFrame, 2 );
imageHeight         = size( backgroundFrame, 1 );

fprintf( 'Choose from grid desired virtual mics\n' )

figure( 'NumberTitle', 'off', 'Name', 'Select sources and define position', 'units', 'pixel', ...
                          'innerposition', [ 0 30 imageWidth imageHeight  ], 'menubar', 'none' );
subplot( 'Position', [ 0 0 1 1 ] );

% show background color image centered in O(0;0) with cartesian coordinates
imshow( flipud( backgroundFrame ), 'XData', [ -imageWidth/2, imageWidth/2 ], 'YData', [ -imageHeight/2, +imageHeight/2 ] );
set( gcf, 'PaperUnits', 'points', 'PaperPosition', [ 0 0 imageWidth/2 imageHeight/2 ] )
set( gca, 'YDir', 'normal' )
xticks( [ -imageWidth/2 -imageWidth/(8/3) -imageWidth/4 -imageWidth/8 0 imageWidth/8 imageWidth/4 imageWidth/(8/3) imageWidth/2 ] )
xticklabels( { '-180', '-135', '-90', '-45', '0', '45', '90', '135', '180' } )
yticks( [ -imageHeight/2 -imageHeight/4 0 imageHeight/4 imageHeight/2 ] )
yticklabels( { '-90', '-45', '0', '45', '90' } )
axis on
hold on
scatter( X, Y, 50, 'filled' );                                          % plot grid on background image

% add marker for each point of grid
for index = 1 : virtualMicNumber
    t           = text( X( index ), Y( index ), num2str( index ), 'HorizontalAlignment', 'right' );
    t.Color     = 'white';
    t.FontSize  = 12;
end

% user makes the selection of virtual sources
i                       = 1;
counter                 = 1;
virtualSources          = 0;
azimuth                 = 0;
elevation               = 0;
while i > 0
    prompt              = 'Virtual mic number ( 0 to stop ): ';
    i                   = input( prompt );
    if i == 0
        close all
        break
    end

    [ virtualSources ]  = [ virtualSources; i ];

    [ x, y ]            = ginput( 1 );

    [ azimuth ]         = [ azimuth; -x / ( imageWidth/2 ) * pi ];
    [ elevation ]       = [ elevation; y / ( imageHeight/2 ) * pi/2 * cos( y / ( imageHeight/2 ) ) ];

    h1                  = text( x(1), y(1), num2str(counter), 'HorizontalAlignment', 'center', 'Color', [ 1 0 0 ], 'FontSize', 14 );
    counter             = counter + 1;
    clear x y h1
end

virtualSources          = virtualSources( 2 : end ); % take only effective choosen sources
virtualSourcesNum       = size( virtualSources, 1 );
azimuth                 = azimuth( 2 : end );        % take only effective choosen positiona
elevation               = elevation( 2 : end );      % take only effective choosen positions

for i = 1 : virtualSourcesNum
    spsFormatAudio(:,i) = spsFormat( :, virtualSources( i ) );              % do selection
end