% staticColorMap.m This function plot a static colormap superimposed to a black/white
% background image

function [ Image ] = staticColorMap( Image, imageWidth, imageHeight, XI, YI, ZI, lowerLimit, upperLimit, contourSpan, alpha, ...
                                     contourEnable, useFixedSplPlotBounds, fixedLowerLimit, fixedUpperLimit, valueTickEnable, cmap )

% background image is grey-scale with three channels so it will not be affected by the colormap later on
imshow( Image, 'XData', [-imageWidth/2, imageWidth/2], 'YData', [-imageHeight/2, +imageHeight/2] ); 
set( gcf, 'PaperUnits', 'points', 'PaperPosition', [ 0 0 imageWidth/2 imageHeight/2 ] )
set( gca, 'YDir', 'normal' );
xticks([-imageWidth/2 -imageWidth/(8/3) -imageWidth/4 -imageWidth/8 0 imageWidth/8 imageWidth/4 imageWidth/(8/3) imageWidth/2])
xticklabels( { '-180', '-135', '-90', '-45', '0', '45', '90', '135', '180' } )
yticks( [ -imageHeight/2 -imageHeight/4 0 imageHeight/4 imageHeight/2 ] )
yticklabels( { '-90', '-45', '0', '45', '90' } )
axis on
hold on

colormap( cmap )                                                                % define color set
% warning: axis are flipped so XI has to change sign
pcolor( -XI, YI, ZI );                                                      % compute color map
shading interp                                                              % better quality setting for colormap

if useFixedSplPlotBounds == 1
    caxis( [ fixedLowerLimit fixedUpperLimit ] );                           % set absolute limits to Z-axis [dB]
    v           = fixedLowerLimit : contourSpan : fixedUpperLimit;          % iso-line levels
else                         
    caxis( [ lowerLimit upperLimit ] )                                      % set relative limits to Z-axis [dB]
    v           = lowerLimit : contourSpan : upperLimit;                    % iso-line levels
end

hand_axes       = get( gcf, 'children' );

if contourEnable && valueTickEnable
    [ C, ~ ]    = contour( -XI, YI, ZI, v, 'k' );                           % compute iso-lines
    hand_surf   = get( hand_axes, 'children' );
    set( hand_surf(2), 'facealpha', alpha );                                % set transparency
    set( hand_surf(2), 'linestyle', 'none' );
    set( hand_surf(1), 'linecolor', 'black' );                              % set color lines to black
    clabel( C );
elseif contourEnable
    contour( -XI, YI, ZI, v, 'k' );                                         % compute iso-lines
    hand_surf   = get( hand_axes, 'children' );
    set( hand_surf(2), 'facealpha', alpha );                                % set transparency
    set( hand_surf(2), 'linestyle', 'none' );
    set( hand_surf(1), 'linecolor', 'black' );                              % set color lines to black
else
    hand_surf   = get( hand_axes, 'children' );
    set( hand_surf(1), 'facealpha', alpha );                                % set transparency
end

colorbar                                                                    % show colormap legend on right side

hold off
