% staticTFfilter.m This function perform coherence analysis on em32recorded
% tracks using only one transfer function and filtering in time domain

function [ audioCoherent ] = staticTFfilter( referenceSignal, audioSignal, bandpassLowCutFreq, bandpassHighCutFreq, ...
                                             filteringEnable, fs )

virtualMicNumber        = size( audioSignal, 2 );
referenceNumber         = size( referenceSignal, 2 );

if filteringEnable % suggest minimum value for nfft, depending on freq. windowing
    nfftMin             = 2 ^ ( nextpow2( 2 * ( bandpassHighCutFreq - bandpassLowCutFreq ) ) );
    fprintf( [ 'Nfft minimum value for correct filtering is: ' num2str( nfftMin ) '\n' ] )
else
    nfftMin             = 0;
end

% define nfft value
[ nfft ]                = checkTFnfft( referenceSignal, audioSignal );
if nfft < nfftMin
    fprintf( [ '\nChosed value ( ' num2str( nfft ) ' ) is not allowed\n' ] )
    fprintf( [ 'Nfft setted to min possible value ( ' num2str( nfftMin ) ' )\n' ] )
    nfft                = nfftMin;
    fprintf( 'Press any key to continue or CTRL+C to abort\n' )
    pause
end

% define window for TF
win                     = hann( nfft );
win                     = repelem( win, 1, virtualMicNumber );

% define filtering window
if filteringEnable
    if nfft < 2 * ( bandpassHighCutFreq - bandpassLowCutFreq )
        error( 'Filter window is too large or nfft is too low\n' );
    end
    
    [ freqWindowing ]   = bandpassFreqFilt( bandpassHighCutFreq, bandpassLowCutFreq, ...
                                                       nfft, fs, virtualMicNumber ); % generate freq. window
    freqWindowing       = single( freqWindowing ); % convert data type
           
end

% pre allocate memory
audioCoherent           = zeros( length( audioSignal )+nfft, virtualMicNumber );

if referenceNumber > 1
    audioCoherentTot    = zeros( length( audioSignal ), virtualMicNumber, referenceNumber );
end

for i = 1 : referenceNumber
    
    fprintf( [ 'Filtering reference ' num2str( i ) '\n' ] )
    
    % calculate transfer function
    fprintf( 'Calculating total transfer function\n\n' );
    transferFunction    = tfestimate( referenceSignal( :, i ), audioSignal, hann( nfft ), nfft/2, nfft );

    if filteringEnable

        transferFunction = transferFunction .* freqWindowing;

    end
    
    fprintf( 'Calculating coherence filtering\n' );
    
    % go back to time domain
    transferFunction    = [ zeros( 1, virtualMicNumber ); transferFunction( 2 : end - 1,: ); ...
                            zeros( 1, virtualMicNumber ); flipud( conj( transferFunction( 2 : end - 1, : ) ) ) ];
    tfIR                = fftshift( ifft( transferFunction ) );
    tfIRwin             = tfIR .* win;

    referenceRepeted    = repelem( referenceSignal( :, i ), 1, virtualMicNumber );
    audioCoherent       = fftfilt( double( tfIRwin ), double( [ referenceRepeted; zeros( nfft, virtualMicNumber ) ] ) );
    
    [ ~, delay ]        = max( tfIRwin( :, : ) );
    delay               = max( delay );
    audioCoherent       = audioCoherent( delay+1 : delay+length(audioSignal), : );
    audioCoherentTot(:,:,i) = audioCoherent;
    
end

fprintf ( '\nDONE\n' )

audioCoherent           = sum( audioCoherentTot, 3 );
audioCoherent           = single( audioCoherent );
