% staticTFfilter1to1.m This function perform coherence analysis on em32recorded
% tracks using only one transfer function and filtering in time domain

function [ audioCoherentTot ] = staticTFfilter1to1( referenceSignal, audioSignal, bandpassLowCutFreq, bandpassHighCutFreq, ...
                                                 filteringEnable )

referenceNumber         = size( referenceSignal, 2 );
referenceLength         = size( referenceSignal, 1 );

if filteringEnable % suggest minimum value for nfft, depending on freq. windowing
    nfftMin             = 2 ^ ( nextpow2( 2 * ( bandpassHighCutFreq - bandpassLowCutFreq ) ) );
    fprintf( [ 'Nfft minimum value is: ' num2str( nfftMin ) '\n' ] )
end

% define nfft value
[ nfft ]                = checkTFnfft( referenceSignal, audioSignal );

% define window for TF
win                     = hann( nfft );

% define filtering window
if filteringEnable
    if nfft < 2 * ( bandpassHighCutFreq - bandpassLowCutFreq )
        error( 'Filter window is too large or nfft is too low\n' );
    end
    
    [ freqWindowing ]   = bandpassFreqFilt( bandpassHighCutFreq, bandpassLowCutFreq, ...
                                            nfft, fs, 1 ); % generate freq. window
    freqWindowing       = single( freqWindowing ); % convert data type
           
end

% pre allocate memory
audioCoherent           = zeros( referenceLength, 1 );

if referenceNumber > 1
    audioCoherentTot    = zeros( length( audioSignal ), referenceNumber );
    audioCoherentTot    = single( audioCoherentTot );
end

for i = 1 : referenceNumber
    
    fprintf( [ 'Filtering reference ' num2str( i ) '\n' ] )
    
    % calculate transfer function
    fprintf( 'Calculating total transfer function\n\n' );
    transferFunction    = tfestimate( referenceSignal( :, i ), audioSignal( :, i ), hann( nfft ), nfft/2, nfft );

    if filteringEnable

        transferFunction = transferFunction .* freqWindowing;

    end
    
    fprintf( 'Calculating coherence filtering\n\n' );
    
    % go back to time domain
    transferFunction    = [ 0; transferFunction( 2 : end - 1,: ); ...
                            0; flipud( conj( transferFunction( 2 : end - 1, : ) ) ) ];
    tfIR                = fftshift( ifft( transferFunction ) );
    tfIRwin             = tfIR .* win;

    %referenceRepeted    = repelem( referenceSignal( :, i ), 1, virtualMicNumber );
    audioCoherent       = fftfilt( double( tfIRwin ), double( [ referenceSignal(:,1); zeros( nfft, 1 ) ] ) );
    
    [ ~, delay ]        = max( tfIRwin( :, : ) );
    audioCoherent       = audioCoherent( delay+1 : delay+length(audioSignal), : );
    audioCoherentTot(:,i) = audioCoherent;
    
end

audioCoherentTot        = single( audioCoherent );
