% syncAudioVideo.m This function perform auto sync between EigenMike and
% audio recorded by camera

function [ signal, referenceMic, videoTimeToSkip, EMrecorded ] = syncAudioVideo( signal, audioVideo, fsVideo, ...
                                                                                 referenceMic, EMrecorded )
% extract signals for computing delay
firstSignal             = signal( :, 1);                % take only the first capsule
audioVideo              = audioVideo( :, 1 );           % if more than 1 (stereo) take only first

% define signal length
signalLength            = length( firstSignal );
refLength               = length( audioVideo );

% define nfft optimum value
exp                     = nextpow2( min( signalLength, refLength ) ) - 2;
if exp > 20
    exp = 20;
end
nfftSync                = 2^exp;

% compute transfer function
tf                      = tfestimate( firstSignal(1:min( signalLength, refLength ) ), ...
                                      audioVideo(1:min( signalLength, refLength ) ), ...
                                      hann( nfftSync ), nfftSync/4, nfftSync );

tf                      = [ 0; tf( 2 : end - 1 ); 0; flipud( conj( tf( 2 : end - 1 ) ) ) ];
tfIR                    = fftshift( ifft( tf ) );
[ ~, idx ]              = max( tfIR );
delay                   = idx - nfftSync/2;

% apply delay
if delay >= 0
    
    videoTimeToSkip     = delay / fsVideo;
    
    if signalLength > refLength - delay
        
        signal          = signal( 1 : refLength - delay, :);
        
        if numel( EMrecorded ) ~= 1
            EMrecorded      = EMrecorded( 1 : refLength - delay, :);
        end
        
        if numel( referenceMic ) ~= 1
            referenceMic = referenceMic( 1 : refLength - delay, : );
        end
        
    end
    
else
    
    videoTimeToSkip     = 0;
    delay               = - delay;
    signal              = signal( delay : end, :);
    
    if numel( EMrecorded ) ~= 1
        EMrecorded          = EMrecorded( delay : end, :);
    end
    
    if numel( referenceMic ) ~= 1
        referenceMic    = referenceMic( delay : end, : );
    end
    
    if length( signal ) > refLength
        
        signal          = signal( 1 : refLength, : );
        
        if numel( EMrecorded ) ~= 1
            EMrecorded      = EMrecorded( 1 : refLength, : );
        end
        
        if numel( referenceMic ) ~= 1
            referenceMic = referenceMic( 1 : refLength, : );
        end
        
    end 
    
end
        