% syncReference.m This function calculate delay between 2 signals
function [ delay ] = syncReference( signal, reference )

% extract signals for computing delay
meanSignal              = mean( signal, 2 );
referenceNum            = size( reference, 2 );
refLength               = size( reference, 1 );
signalLength            = size( meanSignal, 1 );
longest                 = max( signalLength, refLength );

if signalLength > refLength
    reference           = [ reference; zeros( signalLength - refLength, referenceNum ) ];
elseif signalLength < refLength
    meanSignal          = [ meanSignal; zeros( refLength - signalLength, 1 ) ];
end

% define nfft optimum value
exp                     = nextpow2( longest ) - 2;
% if exp > 20
%     exp = 20;
% end
nfftSync                = 2^exp;

delay                   = zeros( referenceNum, 1 );

for i = 1 : referenceNum
       
    % compute transfer function
    tf                  = tfestimate( meanSignal, reference( :, i ), ...
                                      hann( nfftSync ), nfftSync/4, nfftSync );
                                                                    
    tf                  = [ 0; tf( 2 : end - 1 ); 0; flipud( conj( tf( 2 : end - 1 ) ) ) ];
    tfIR                = fftshift( ifft( tf ) );
    
    % calculate delay
    [ ~, idx ]          = max( tfIR );
    delayRef            = idx - nfftSync/2;
    delay ( i )         = delayRef;
           
end
