% videoColorMap.m This function plot a colormap for video superimposed to a black/white background image

function [ ] = videoColorMap( picture, imageWidth, imageHeight, XI, YI, ZI, lowerLimit, upperLimit, plotBG, v, alpha, ...
                              contourEnable, useFixedSplPlotBounds, fixedLowerLimit, fixedUpperLimit, valueTickEnable, cmap )

% background image is grey-scale with three channels so it will not be affected by the colormap later on
image( picture, 'XData', [-imageWidth/2, imageWidth/2], 'YData', [-imageHeight/2, +imageHeight/2] ); 
axis off
set( plotBG, 'YDir', 'normal' )                                             % correct image axis
hold on

% compute color map                                                    
fig         = pcolor( -XI, YI, ZI );
colormap( cmap )                                                             % define color set
shading interp                                                              % better quality setting for colormap
set( fig, 'facealpha', alpha );                                             % set transparency

if useFixedSplPlotBounds == 1
    caxis( [ fixedLowerLimit fixedUpperLimit ] );                           % set absolute limits to Z-axis [dB]
else                         
    caxis( [ lowerLimit upperLimit ] )                                      % set relative limits to Z-axis [dB]
end

if contourEnable && valueTickEnable
    [ C, ~ ] = contour( -XI, YI, ZI, v , 'k' );                             % compute iso-lines
    clabel( C );
elseif contourEnable
    contour( -XI, YI, ZI, v , 'k' );                                        % compute iso-lines
end

hold off
